import request from '@/router/axios';

export function redemptionNoticePageApi(data) {
  return request({
    url: `/admin/wmscorepackage/redemption/notice/page`,
    method: 'get',
    params: data
  });
}

export function redemptionValStatApi(pkg_id) {
  return request({
    url: `/admin/wmscorepackage/redemption/val/stat/${pkg_id}`,
    method: 'get'
  });
}

export function redemptionNoticeCreate(data) {
  return request({
    url: `/admin/wmscorepackage/redemption/notice/create`,
    method: 'post',
    data
  });
}

export function redemptionNoticeReadApi(data) {
  return request({
    url: `/admin/wmscorepackage/redemption/notice/read`,
    method: 'post',
    data
  });
}

export function redemptionNoticeConfirmApi(data) {
  return request({
    url: `/admin/wmscorepackage/redemption/notice/confirm`,
    method: 'post',
    data
  });
}

export function redemptionPkgListApi() {
  return request({
    url: `/admin/wmscorepackage/redemption/pkg/list`,
    method: 'get'
  });
}

export function redemptionoticeCheckApi(data) {
  return request({
    url: `/admin/wmscorepackage/redemption/notice/check`,
    method: 'post',
    data
  });
}
